--- Fl_Menu_.cxx	2003-01-30 13:42:11.000000000 -0800
+++ Fl_Menu_.cxx.new	2004-02-11 08:40:11.000000000 -0800
@@ -36,6 +36,43 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+// Set 'pathname' of specified menuitem
+//    If finditem==NULL, mvalue() is used (the most recently picked menuitem)
+//    Returns:
+//       0 : OK
+//      -1 : item not found (name="")
+//      -2 : 'name' not large enough (name="")
+//
+#define SAFE_STRCAT(s) \
+    { len += strlen(s); if ( len >= namelen ) { *name='\0'; return(-2); } else strcat(name,(s)); }
+int Fl_Menu_::item_pathname(char *name, int namelen, const Fl_Menu_Item *finditem) const {
+    int len = 0;
+    finditem = finditem ? finditem : mvalue();    
+    name[0] = '\0';
+    for ( int t=0; t<size(); t++ ) {
+        const Fl_Menu_Item *m = &(menu()[t]);
+	if ( m->submenu() ) {				// submenu? descend
+	    if ( *name ) SAFE_STRCAT("/");
+	    SAFE_STRCAT(m->label());
+	} else {
+	    if ( m->label() ) {				// menu item?
+		if ( m == finditem ) {			// found? tack on itemname, done.
+		    SAFE_STRCAT("/");
+		    SAFE_STRCAT(m->label());
+		    return(0);
+		}
+	    } else {					// end of submenu? pop
+	        char *ss = strrchr(name, '/');
+		if ( ss ) { *ss = 0; len = strlen(name); }	// "File/Edit" -> "File"
+		else { name[0] = '\0'; len = 0; }		// "File" -> ""
+		continue;
+	    }
+	}
+    }
+    *name = '\0';
+    return(-1);						// item not found
+}
+
 int Fl_Menu_::value(const Fl_Menu_Item* m) {
   clear_changed();
   if (value_ != m) {value_ = m; return 1;}
